==> haskell-bifunctors-5.5.10-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bifunctors
version:              5.5.10
visibility:           public
id:                   bifunctors-5.5.10-H8DMQZCdbDbJ8yspZaxtc4
key:                  bifunctors-5.5.10-H8DMQZCdbDbJ8yspZaxtc4
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/bifunctors/
synopsis:             Bifunctors
description:          Bifunctors.
category:             Data, Functors
abi:                  26638393ec6fea5f9cfc50fec7ff7623
exposed:              True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biap Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.TH
    Data.Bifunctor.Tannen Data.Bifunctor.Wrapped

hidden-modules:       Data.Bifunctor.TH.Internal Paths_bifunctors
import-dirs:          /usr/lib/ghc-8.10.3/site-local/bifunctors-5.5.10
library-dirs:         /usr/lib/ghc-8.10.3/site-local/bifunctors-5.5.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/bifunctors-5.5.10
hs-libraries:         HSbifunctors-5.5.10-H8DMQZCdbDbJ8yspZaxtc4
includes:             bifunctors-common.h
depends:
    base-4.14.1.0 base-orphans-0.8.4-7lqxW9sQ8zeE95t0PqfulJ
    comonad-5.0.8-E5ukj1diH4u6kDbgrzLaH2 containers-0.6.2.1
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C template-haskell-2.16.0.0
    th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html:         /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bifunctors-5.5.10-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bifunctors
version:              5.5.10
visibility:           public
id:                   bifunctors-5.5.10-1vB1PFNRpxeCZqtU4izYXb
key:                  bifunctors-5.5.10-1vB1PFNRpxeCZqtU4izYXb
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/bifunctors/
synopsis:             Bifunctors
description:          Bifunctors.
category:             Data, Functors
abi:                  71a5170db1f87bd4066b1bd1e37f3add
exposed:              True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biap Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.TH
    Data.Bifunctor.Tannen Data.Bifunctor.Wrapped

hidden-modules:       Data.Bifunctor.TH.Internal Paths_bifunctors
import-dirs:          /usr/lib/ghc-8.10.4/site-local/bifunctors-5.5.10
library-dirs:         /usr/lib/ghc-8.10.4/site-local/bifunctors-5.5.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/bifunctors-5.5.10
hs-libraries:         HSbifunctors-5.5.10-1vB1PFNRpxeCZqtU4izYXb
includes:             bifunctors-common.h
depends:
    base-4.14.1.0 base-orphans-0.8.4-6Z8Eg84NK7u5UGWcrnUfUX
    comonad-5.0.8-KlhQMLXsEFDEd8v5oNUYvk containers-0.6.2.1
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C template-haskell-2.16.0.0
    th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html:         /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
